TrackEventPayload class

A custom analytics event for PushEngage.trackEvent.

eventName is required and must be non-empty. provider and eventType default to "PushEngage" and "PushEngage.CustomEvent" in the native SDK when omitted. Unset optional fields are not sent.

Implemented types

Constructors

TrackEventPayload({required String eventName, Map<String, Object>? data, String? profileId, String? provider, String? eventType})

Properties

data Map<String, Object>?
final
eventName String
final
eventType String?
final
hashCode int
The hash code for this object.
no setterinherited
profileId String?
final
provider String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited