IdentifyFields class
The 12 predefined subscriber identification fields (Web SDK parity).
Only the fields you set are sent; unset (null) fields are omitted. Values may be a String, num, or bool. Passed to PushEngage.identify.
- Implemented types
Constructors
Properties
- city → Object?
-
final
- country → Object?
-
final
- dob → Object?
-
final
- email → Object?
-
final
- firstName → Object?
-
final
- gender → Object?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- language → Object?
-
final
- lastName → Object?
-
final
- phone → Object?
-
final
- profileId → Object?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → Object?
-
final
- zip → Object?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited